==> knative-model-4.12.0-sources.jar: io/fabric8/knative/serving/v1beta1/ConfigurationBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigurationBuilder extends io.fabric8.knative.serving.v1beta1.ConfigurationFluentImpl<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.Configuration,io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> {

    io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigurationBuilder() { 
        this(true);
    }


    public ConfigurationBuilder(Boolean validationEnabled) { 
        this(new Configuration(), validationEnabled);
    }


    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent) { 
        this(fluent, true);
    }


    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new Configuration(), validationEnabled);
    }


    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Configuration instance) { 
        this(fluent, instance, true);
    }


    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Configuration instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.Configuration instance) { 
        this(instance,true);
    }


    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.Configuration instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.knative.serving.v1beta1.Configuration build() {
        Configuration buildable = new Configuration(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigurationBuilder that = (ConfigurationBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: io/fabric8/knative/serving/v1beta1/ConfigurationBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigurationBuilder extends io.fabric8.knative.serving.v1beta1.ConfigurationFluentImpl<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.Configuration,io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> {

    io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigurationBuilder() {
        this(true);
    }

    public ConfigurationBuilder(Boolean validationEnabled) {
        this(new Configuration(), validationEnabled);
    }

    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Configuration(), validationEnabled);
    }

    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Configuration instance) {
        this(fluent, instance, true);
    }

    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.ConfigurationFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Configuration instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.Configuration instance) {
        this(instance,true);
    }

    public ConfigurationBuilder(io.fabric8.knative.serving.v1beta1.Configuration instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableConfiguration build() {
        EditableConfiguration buildable = new EditableConfiguration(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigurationBuilder that = (ConfigurationBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
